language en

# CELINE Core Ontology

Imported Ontologies:
  bigg4kpi#
  ontology#
  time
  <http://www.w3.org/ns/sosa/>
  <http://xmlns.com/foaf/0.1/>
  peco-core
  <https://saref.etsi.org/core/>
  <https://saref.etsi.org/core/>
  <https://saref.etsi.org/saref4ener/>
Download serialization:
License:
Cite as:
  CELINE Core Ontology.

Provenance of this page

Ontology Specification Draft

## Acknowledgments back to ToC

The authors would like to thank Silvio Peroni for developing LODE, a Live OWL Documentation Environment, which is used for representing the Cross Referencing Section of this document and Daniel Garijo for developing Widoco, the program used to create the template used in this documentation.